<template>

    <div class="row">

        <div class="col-md-8 ">
            <tabs :tabs="tabs">
                <template  slot="upload_file">
                    <component :is="fromComputer"
                               @media-response="mediaResponse"
                               @media-remove="mediaRemove"
                               @media-remove-all-file="mediaRemoveAll"
                    ></component>
                </template>
                <template  slot="media_library">

                    <fromMedia
                            @media-response="mediaResponse"
                            @media-remove="mediaRemove"
                            :selected="medias"
                    ></fromMedia>
                </template>
            </tabs>
        </div>
        <div class="col-md-4">
                <div class="card">
                    <div class="card-body scrollbar" id="selected_list">
                        <ul class="list-group list-group-flush">
                            <li class="list-group-item d-flex align-items-center" v-for="media in medias">
                                <a href="#">
                                    <img :src="media.src" class="avatar">
                                </a>
                                <div class="mx-3">
                                    <a href="#" class="text-dark font-weight-600 text-sm">John Snow</a>
                                    <small class="d-block text-muted">{{media.id}}3 days ago</small>
                                </div>
                            </li>
                        </ul>

                    </div>
                    <div class="card-body">
                        <a class="btn btn-sm btn-primary" @click="apply">Apply</a>
                    </div>

                </div>
        </div>
    </div>
</template>

<script>
    import fromComputerSingle from './from-computer-single';
    import fromComputerMultiple from './from-computer-multiple';
    import fromMedia from './from-media';
    export default {
        props:{
            multiple:{
                type:Boolean,
                default:true
            }
        },
        name: "media-input",
        components:{
            fromComputerSingle: fromComputerSingle,
            fromComputerMultiple: fromComputerMultiple,
            fromMedia: fromMedia,
        },
        data: () => ({
            tabs:[
                {
                    name:'upload_file',
                    label:'Upload File',
                    icon:'<i class="fa fa-desktop"></i>',
                    active:true
                },
                {
                    name:'media_library',
                    label:'Media Library',
                    icon:'<i class="fa fa-language"></i>',
                    active:false
                }
            ],
            inputComponent:'fromComputer',
            medias:[]
        }),
        computed:{
          fromComputer(){
              if(this.multiple){
                  return fromComputerMultiple;
              }
              return fromComputerSingle;
          }
        },
        methods:{
            mediaResponse(response){
                console.log(response);
                this.medias.push(response.data)
            },
            mediaRemove(id){
                this.medias.splice(this.medias.findIndex(function(i){
                    return i.id === id;
                }), 1);

            },
            mediaRemoveAll(){
                this.medias = [];
            },
            mediaReload(){
                alert(1)
            },
            apply(){
                this.$emit('media-apply',this.medias)
            }

        }
    }
</script>

<style scoped>
    #selected_list,
    #library{
        max-height: 300px;
        overflow: auto;
    }
</style>